@@ -9,6 +9,14 @@ def send_email(sender, instance, **kwargs):
     """send the email to the person who requested the token"""
     #
     #
+    # return if we're in silent mode return
+    try:
+        if instance.slient == True:
+            return
+    except AttributeError:
+        pass
+    #
+    #
     # the site
     site = Site.objects.get_current()
     #
